### Sox-Chords  
[![Build Status](https://travis-ci.org/baudcode/sox-chords.svg?branch=master)](https://travis-ci.org/baudcode/sox-chords)

With the sox-chords module you can generate guitar chords using sox.
Currently supported chords are:

- Sus4
- Sus2
- MajorTriad
- MinorTriad
- AugmentedTriad
- DiminishedTriad
- MajorSeventh
- MinorSeventh
- DominantSeventh
- MinorMajorSeventh
- AugmentedSeventh
- AugmentedMajorSeventh
- DiminishedSeventh
- HalfDiminishedSeventh


You can create Scales as well.

For examples please see **examples/How To.ipynb**